@@ -1,9 +1,12 @@
 import re
 import math
 import time
+import logging
 from django.conf import settings
 from log_labeler import LOG_LABEL_OBFUSCATE
 
+logger = logging.getLogger(__name__)
+
 class Utils:
     @classmethod
     def array_difference(cls, array1, array2):
@@ -81,7 +84,10 @@ class Utils:
         if "body" in log_label_obfuscate:
             for pattern, replacement in log_label_obfuscate["body"].items():
                 if re.search(pattern, body):
-                    body = re.sub(pattern, replacement, body)
+                    try:
+                        body = re.sub(pattern, replacement, body)
+                    except re.error as ex:
+                        logger.error("Unable to obfuscate the body: {}".format(str(ex)))
 
         return body
 
@@ -92,7 +98,10 @@ class Utils:
         if "response" in log_label_obfuscate:
             for pattern, replacement in log_label_obfuscate["response"].items():
                 if re.search(pattern, response):
-                    response = re.sub(pattern, replacement, response)
+                    try:
+                        response = re.sub(pattern, replacement, response)
+                    except re.error as ex:
+                        logger.error("Unable to obfuscate the response: {}".format(str(ex)))
 
         return response
 
@@ -102,6 +111,9 @@ class Utils:
         if "url" in log_label_obfuscate:
             for pattern, replacement in log_label_obfuscate["url"].items():
                 if re.search(pattern, url):
-                    url = re.sub(pattern, replacement, url)
+                    try:
+                        url = re.sub(pattern, replacement, url)
+                    except re.error as ex:
+                        logger.error("Unable to obfuscate the url: {}".format(str(ex)))
 
         return url
